@@ -2,14 +2,18 @@
 
 
 import logging
-import urllib
-import urllib2
 import gzip
-from StringIO import StringIO
+from ..bouth23 import s, bstream
+try:
+    from urllib.parse import urlencode
+    from urllib.request import Request, urlopen
+    from urllib.error import HTTPError, URLError
+except ImportError:
+    from urllib import urlencode
+    from urllib2 import Request, urlopen, HTTPError, URLError
 from .exceptions import ISBNToolsHTTPError, ISBNToolsURLError
 
 UA = 'webservice (gzip)'
-
 LOGGER = logging.getLogger(__name__)
 
 
@@ -26,18 +30,18 @@ class WEBService(object):
         # headers to accept gzipped content
         headers = {'Accept-Encoding': 'gzip', 'User-Agent': user_agent}
         # if 'data' it does a PUT request (data must be urlencoded)
-        data = urllib.urlencode(values) if values else None
-        self._request = urllib2.Request(url, data, headers=headers)
+        data = urlencode(values) if values else None
+        self._request = Request(url, data, headers=headers)
         self.response = None
 
     def _response(self):
         try:
-            self.response = urllib2.urlopen(self._request)
-        except urllib2.HTTPError as e:
+            self.response = urlopen(self._request)
+        except HTTPError as e:
             LOGGER.critical('ISBNToolsHTTPError for %s with code %s',
                             self._url, e.code)
             raise ISBNToolsHTTPError(e.code)
-        except urllib2.URLError as e:
+        except URLError as e:
             LOGGER.critical('ISBNToolsURLError for %s with reason %s',
                             self._url, e.reason)
             raise ISBNToolsURLError(e.reason)
@@ -48,12 +52,12 @@ class WEBService(object):
         """
         self._response()
         if self.response.info().get('Content-Encoding') == 'gzip':
-            buf = StringIO(self.response.read())
+            buf = bstream(self.response.read())
             f = gzip.GzipFile(fileobj=buf)
             data = f.read()
         else:
             data = self.response.read()
-        return data
+        return s(data)
 
 
 def query(url, user_agent=UA, values=None):
