@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 
 import os
-import ConfigParser
+try:                                 # pragma: no cover
+    import configparser
+except ImportError:
+    import ConfigParser as configparser
 import socket
 from . import config
 from . import registry
@@ -17,8 +20,8 @@ THREADS_TIMEOUT = float(config.THREADS_TIMEOUT)
 
 try:
     # read conf file
-    conf = ConfigParser.ConfigParser()
-    if os.name == 'nt':
+    conf = configparser.ConfigParser()
+    if os.name == 'nt':              # pragma: no cover
         conf.read([os.path.join(os.getenv('APPDATA'),
                   'isbntools/isbntools.conf')])
     else:
@@ -38,19 +41,19 @@ try:
             if o.upper() == 'DEFAULT_SERVICE':
                 registry.setdefaultservice(v)
                 continue
-            if 'api_key' in o:
+            if 'api_key' in o:       # pragma: no cover
                 name = o[:-8]
                 config.add_apikey(name, v)
             else:
                 config.set_options(o.upper(), v)
 
-    if conf.has_section('PLUGINS'):
+    if conf.has_section('PLUGINS'):  # pragma: no cover
         for o, v in conf.items('PLUGINS'):
             plugin = registry.load_plugin(o, v)
             if plugin:
                 registry.add_service(o, plugin.query)
 
-except:
+except:                              # pragma: no cover
     pass
 
 # socket timeout is not exposed at urllib2 level so I had to import the
